/*
 * Copyright (c) 2016 Samsung Electronics Co., Ltd
 *
 * Licensed under the Flora License, Version 1.1 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://floralicense.org/license/
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

using Xamarin.Forms;

/// <summary>
/// ApplicationStore is a simple app to provide a application store for users.
/// Thus, user can download the Apps
/// </summary>
namespace ApplicationStoreUI
{
    /// <summary>
    /// Main view of ApplicationStore
    /// </summary>
    public class MainView : ContentPage
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="MainView"/> class.
        /// </summary>
        /// <param name="screenWidth">The screen width</param>
        /// <param name="screenHeight">The screen height</param>
        public MainView(int screenWidth, int screenHeight)
        {
            // Add a label as view title
            Label header = new Label
            {
                Text = "Application Store",
                TextColor = Color.White,
                FontSize = 28,
                HeightRequest = screenHeight * 0.075,
                HorizontalOptions = LayoutOptions.Center,
            };

            // 1.Top grid with 6 buttons
            Grid topGrid = new Grid
            {
                RowDefinitions =
                {
                    new RowDefinition { Height = screenHeight * 0.08},
                    new RowDefinition { Height = screenHeight * 0.08},
                    new RowDefinition { Height = screenHeight * 0.08}
                }
            };
            topGrid.Children.Add(CreateButton("Apps", Color.Green), 0, 0);
            topGrid.Children.Add(CreateButton("Games", Color.Green), 1, 0);
            topGrid.Children.Add(CreateButton("Movies", Color.Red), 0, 1);
            topGrid.Children.Add(CreateButton("Music", Color.Orange), 1, 1);
            topGrid.Children.Add(CreateButton("Books", Color.Blue), 0, 2);
            topGrid.Children.Add(CreateButton("Magazines", Color.Navy), 1, 2);

            // 2.Center grid with 3 buttons
            Grid centerGrid = new Grid
            {
                RowDefinitions =
                {
                    new RowDefinition { Height = screenHeight * 0.3}
                }
            };
            centerGrid.Children.Add(CreateButton("Movies1", Color.FromRgb(60, 30, 70)), 0, 0);
            centerGrid.Children.Add(CreateButton("Movies2", Color.FromRgb(50, 80, 30)), 1, 0);
            centerGrid.Children.Add(CreateButton("Movies3", Color.Purple), 2, 0);

            // 3.Bottom grid with 3 buttons
            Grid bottomGrid = new Grid
            {
                RowDefinitions =
                {
                    new RowDefinition { Height = screenHeight * 0.3}
                }
            };
            bottomGrid.Children.Add(CreateButton("Game1", Color.Navy), 0, 0);
            bottomGrid.Children.Add(CreateButton("Game2", Color.Green), 1, 0);
            bottomGrid.Children.Add(CreateButton("Game3", Color.Maroon), 2, 0);

            // 4.Put 3 grids and 2 labels into stack layout
            StackLayout layout = new StackLayout
            {
                Padding = 20,
                BackgroundColor = Color.White,
                Children =
                {
                    topGrid,
                    CreateLabel("New Movie Releases"),
                    centerGrid,
                    CreateLabel("Top Grossing Games"),
                    bottomGrid
                }
            };

            Appearing += (s, e) =>
            {
                Content = new StackLayout
                {
                    Children =
                        {
                            header,
                            new ScrollView
                            {
                                Content = layout
                            }
                        }
                };
            };
        }

        /// <summary>
        /// The method to create a new button.
        /// </summary>
        /// <param name="text">The button's text</param>
        /// <param name="bgColor">The button's background color</param>
        /// <returns>Return the new button</returns>
        private Button CreateButton(string text, Color bgColor)
        {
            Button button = new Button
            {
                Text = text,
                FontSize = 20,
                BackgroundColor = bgColor
            };

            return button;
        }

        /// <summary>
        /// The method to create a new label.
        /// </summary>
        /// <param name="text">The label's text</param>
        /// <returns>Return the new label</returns>
        private Label CreateLabel(string text)
        {
            Label label = new Label
            {
                Margin = new Thickness(0, 10, 0, 0),
                Text = text,
                FontSize = 25
            };

            return label;
        }
    }
}
